read_plaintext_block

Function read_plaintext_block 

fn read_plaintext_block(buffer: &mut Vec<u8>) -> Option<CbcPlaintextBlock>
Reads and removes the first block from the buffer. The size must be checked by the caller before calling this function, and it may panic otherwise.