struct HmacStreamValidator {
hmac: Hmac<Sha256>,
}Expand description
A higher level interface over the HMAC validation of the attachment ciphertext
Fields
hmac: Hmac<Sha256>Implementations
Sourceimpl HmacStreamValidator
impl HmacStreamValidator
fn new(mac_key: &[u8; 32], iv: &[u8; 16]) -> Self
Sourcefn read_block(&mut self, data: &[u8; 16])
fn read_block(&mut self, data: &[u8; 16])
Called on each CBC ciphertext block in order
Sourcefn end_stream(&self) -> [u8; 32]
fn end_stream(&self) -> [u8; 32]
Called after the final block has been ingested by read_block, during encryption.
Sourcefn validate_stream_end(&self, expected_mac: &[u8; 32]) -> bool
fn validate_stream_end(&self, expected_mac: &[u8; 32]) -> bool
Called after the final block has been ingested by read_block, during decryption. Returns
whether the calculated HMAC matches the expected HMAC from the header.